﻿/**
 * Gesture Heatmaps Toolkit (.NET Framework 4.5 C# version)
 *
 * 	    Radu-Daniel Vatavu, Ph.D.
 *	    University Stefan cel Mare of Suceava
 *	    Suceava 720229, Romania
 *	    vatavu@eed.usv.ro
 *
 * 	    Lisa Anthony, Ph.D.
 *      CISE Department
 *      University of Florida
 *      Gainesville, FL 32611 USA
 *      lanthony@cise.ufl.edu
 *	
 *	    Jacob O. Wobbrock, Ph.D.
 * 	    The Information School
 *	    University of Washington
 *	    Seattle, WA 98195-2840
 *	    wobbrock@uw.edu
 *
 * The academic publication for gesture heatmaps, and what should be 
 * used to cite it, is:
 *
 *	Vatavu, R.-D., Anthony, L. and Wobbrock, J.O. (2014).  
 *	  Gesture Heatmaps: Understanding Gesture Performance with Colorful Visualizations. 
 *	  In Proceedings of the 16th ACM on International Conference 
 *	  on Multimodal Interaction (ICMI '14). ACM, New York, NY, USA.
 *	  DOI=10.1145/2663204.2663256 http://dx.doi.org/10.1145/2663204.2663256
 *
 * This software is distributed under the "New BSD License" agreement:
 *
 * Copyright (c) 2014, Radu-Daniel Vatavu, Lisa Anthony, and 
 * Jacob O. Wobbrock. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *    * Neither the names of the University Stefan cel Mare of Suceava, 
 *	    University of Washington, nor University of Florida, nor the names of its contributors 
 *	    may be used to endorse or promote products derived from this software 
 *	    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL Radu-Daniel Vatavu OR Lisa Anthony
 * OR Jacob O. Wobbrock BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
**/

using System;
using System.Windows.Forms;
using System.Collections.Generic;
using System.IO;
using System.Drawing;

namespace GHoST
{
    public partial class FormMain
    {
        private void exportImageToolStripMenuItem_Click(object sender, EventArgs e)
        {
            saveFileDialog1.Filter = "Bitmap files (*.bmp) | *.bmp";
            saveFileDialog1.AddExtension = true;
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                using (Bitmap bitmap = new Bitmap(Math.Max(pbHeatmap.Image.Width, pbHeatmapScale.Image.Width), pbHeatmap.Image.Height + pbHeatmapScale.Image.Height + 10))
                using (Graphics graphics = Graphics.FromImage(bitmap))
                {
                    graphics.Clear(Color.White);
                    graphics.DrawImage(pbHeatmap.Image, (bitmap.Width - pbHeatmap.Image.Width) / 2, 0);
                    graphics.DrawImage(pbHeatmapScale.Image, (bitmap.Width - pbHeatmapScale.Image.Width) / 2, pbHeatmap.Image.Height);
                    bitmap.Save(saveFileDialog1.FileName, System.Drawing.Imaging.ImageFormat.Bmp);
                }
            }
        }

        private void exportFeatureDataToolStripMenuItem_Click(object sender, EventArgs e)
        {
            saveFileDialog1.Filter = "CSV files (*.csv) | *.csv";
            saveFileDialog1.AddExtension = true;
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                using (StreamWriter writer = new StreamWriter(saveFileDialog1.FileName))
                {
                    int numPoints = _centroidFeatureValues[0].Length;
                    writer.Write("Gesture,");
                    for (int i = 1; i <= numPoints; i++)
                        writer.Write("Point{0}{1}", i, i == numPoints ? "" : ",");
                    writer.WriteLine();

                    List<string> userSelectedGestureTypes = GetCheckedGestureTypes();
                    int index = 0;
                    foreach (KeyValuePair<string, GestureSet> gestures in _dataset)
                        if (userSelectedGestureTypes.Contains(gestures.Key))
                        {
                            writer.Write("{0},", gestures.Key);
                            for (int i = 0; i < numPoints; i++)
                                writer.Write("{0}{1}", _centroidFeatureValues[index][i], i == numPoints - 1 ? "" : ",");
                            writer.WriteLine();
                            index++;
                        }
                }
            }
        }
    }
}
